@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*-
 __doc__ = """Fast hierarchical clustering routines for R and Python
 
-Copyright © 2011 Daniel Müllner
-<http://danifold.net>
+Copyright:
+Until package version 1.1.23: © 2011 Daniel Müllner <http://danifold.net>
+All changes from version 1.1.24 on: © Google Inc. <http://google.com>
 
 This module provides fast hierarchical clustering routines. The "linkage"
 method is designed to provide a replacement for the “linkage” function and
@@ -19,11 +20,11 @@ also be obtained at <http://danifold.net/fastcluster.html>.
 """
 
 __all__ = ['single', 'complete', 'average', 'weighted', 'ward', 'centroid', 'median', 'linkage', 'linkage_vector']
-__version_info__ = ('1', '1', '12')
+__version_info__ = ('1', '1', '28')
 __version__ = '.'.join(__version_info__)
 
-from numpy import double, empty, array, ndarray, var, cov, dot, bool, \
-    expand_dims, ceil, sqrt
+from numpy import double, empty, array, ndarray, var, cov, dot, expand_dims, \
+    ceil, sqrt
 from numpy.linalg import inv
 try:
     from scipy.spatial.distance import pdist
@@ -31,7 +32,7 @@ except ImportError:
     def pdist(*args, **kwargs):
         raise ImportError('The fastcluster.linkage function cannot process '
                           'vector data since the function '
-                          'scipy.partial.distance.pdist could not be  '
+                          'scipy.spatial.distance.pdist could not be  '
                           'imported.')
 from _fastcluster import linkage_wrap, linkage_vector_wrap
 
@@ -70,6 +71,7 @@ def median(D):
 (alias). See the help on the “linkage” function for further information.'''
     return linkage(D, method='median')
 
+# This dictionary must agree with the enum method_codes in fastcluster.cpp.
 mthidx = {'single'   : 0,
           'complete' : 1,
           'average'  : 2,
@@ -79,7 +81,7 @@ mthidx = {'single'   : 0,
           'median'   : 6 }
 
 def linkage(X, method='single', metric='euclidean', preserve_input=True):
-    '''Hierarchical, agglomerative clustering on a dissimilarity matrix or on
+    r'''Hierarchical, agglomerative clustering on a dissimilarity matrix or on
 Euclidean data.
 
 Apart from the argument 'preserve_input', the method has the same input
@@ -233,18 +235,19 @@ and simply ignores the mask.'''
         NN = len(X)
         N = int(ceil(sqrt(NN*2)))
         if (N*(N-1)//2) != NN:
-            raise ValueError('The length of the condensed distance matrix '
-                             'must be (k \choose 2) for k data points!')
+            raise ValueError(r'The length of the condensed distance matrix '
+                             r'must be (k \choose 2) for k data points!')
     else:
         assert X.ndim==2
         N = len(X)
-        X = pdist(X, metric)
+        X = pdist(X, metric=metric)
         X = array(X, dtype=double, copy=False, order='C', subok=True)
     Z = empty((N-1,4))
     if N > 1:
         linkage_wrap(N, X, Z, mthidx[method])
     return Z
 
+# This dictionary must agree with the enum metric_codes in fastcluster_python.cpp.
 mtridx = {'euclidean'      :  0,
           'minkowski'      :  1,
           'cityblock'      :  2,
@@ -272,7 +275,7 @@ booleanmetrics = ('yule', 'matching', 'dice', 'kulsinski', 'rogerstanimoto',
                   'sokalmichener', 'russellrao', 'sokalsneath', 'kulsinski')
 
 def linkage_vector(X, method='single', metric='euclidean', extraarg=None):
-    '''Hierarchical (agglomerative) clustering on Euclidean data.
+    r'''Hierarchical (agglomerative) clustering on Euclidean data.
 
 Compared to the 'linkage' method, 'linkage_vector' uses a memory-saving
 algorithm. While the linkage method requires Θ(N^2) memory for
